==> haskell-hasql-dynamic-statements-0.3.1.1-92-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-ElNtim2hNoB6mqp8P1dueZ
key:                  hasql-dynamic-statements-0.3.1.1-ElNtim2hNoB6mqp8P1dueZ
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  05dd2e2792fb0d156485182600839deb
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-ElNtim2hNoB6mqp8P1dueZ
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hasql-1.5.0.4-3X2mZlxdWL044URuQ7OkF4
    hasql-implicits-0.1.0.5-3ntSl15XuVyATu9fySK9qe
    ptr-0.16.8.6-LdGNX0ABBqk5KGcTGUMFOY

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-dynamic-statements-0.3.1.1-106-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-dynamic-statements.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-dynamic-statements
version:              0.3.1.1
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.1-1wfKmaJD5gp34LSU8AmrNq
key:                  hasql-dynamic-statements-0.3.1.1-1wfKmaJD5gp34LSU8AmrNq
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  a893100f72acd8ac456303d04867dc89
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hasql-dynamic-statements-0.3.1.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hasql-dynamic-statements-0.3.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.1-1wfKmaJD5gp34LSU8AmrNq
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hasql-1.5.0.4-6GDwBu1ouGLL97aqfLNtDJ
    hasql-implicits-0.1.0.5-A567VS4KtbzBSEEtSvy8a8
    ptr-0.16.8.6-9h6yR4L9aC69WVGhBLfYTA

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
